Class: Amazon::Element
- Inherits:
-
Object
- Object
- Amazon::Element
- Defined in:
- lib/amazon/ecs.rb
Overview
Internal wrapper class to provide convenient method to access Nokogiri element value.
Class Method Summary collapse
-
.get(element, path = '.') ⇒ Object
Return the text value of an element.
-
.get_array(element, path = '.') ⇒ Object
Return an array of values based on the given path.
-
.get_hash(element, path = '.') ⇒ Object
Return child element text values of the given path.
-
.get_unescaped(element, path = '.') ⇒ Object
Return an unescaped text value of an element.
Instance Method Summary collapse
-
#/(path) ⇒ Object
Returns a Nokogiri::XML::NodeSet of elements matching the given path.
- #attributes ⇒ Object
-
#elem ⇒ Object
Returns Nokogiri::XML::Element object.
-
#get(path = '.') ⇒ Object
Get the text value of the given path, leave empty to retrieve current element value.
-
#get_array(path = '.') ⇒ Object
Get the array values of the given path.
-
#get_element(path) ⇒ Object
Similar with search_and_convert but always return first element if more than one elements found.
-
#get_elements(path) ⇒ Object
Return an array of Amazon::Element matching the given path.
-
#get_hash(path = '.') ⇒ Object
Get the children element text values in hash format with the element names as the hash keys.
-
#get_unescaped(path = '.') ⇒ Object
Get the unescaped HTML text of the given path.
-
#initialize(element) ⇒ Element
constructor
Pass Nokogiri::XML::Element object.
- #to_s ⇒ Object
Constructor Details
#initialize(element) ⇒ Element
Pass Nokogiri::XML::Element object
333 334 335 |
# File 'lib/amazon/ecs.rb', line 333 def initialize(element) @element = element end |
Class Method Details
.get(element, path = '.') ⇒ Object
Return the text value of an element.
291 292 293 294 295 296 |
# File 'lib/amazon/ecs.rb', line 291 def get(element, path='.') return unless element result = element.at_xpath(path) result = result.inner_html if result result end |
.get_array(element, path = '.') ⇒ Object
Return an array of values based on the given path.
305 306 307 308 309 310 311 312 313 314 |
# File 'lib/amazon/ecs.rb', line 305 def get_array(element, path='.') return unless element result = element/path if (result.is_a? Nokogiri::XML::NodeSet) || (result.is_a? Array) result.collect { |item| self.get(item) } else [self.get(result)] end end |
.get_hash(element, path = '.') ⇒ Object
Return child element text values of the given path.
317 318 319 320 321 322 323 324 325 326 327 328 329 |
# File 'lib/amazon/ecs.rb', line 317 def get_hash(element, path='.') return unless element result = element.at_xpath(path) if result hash = {} result = result.children result.each do |item| hash[item.name] = item.inner_html end hash end end |
.get_unescaped(element, path = '.') ⇒ Object
Return an unescaped text value of an element.
299 300 301 302 |
# File 'lib/amazon/ecs.rb', line 299 def get_unescaped(element, path='.') result = self.get(element, path) CGI::unescapeHTML(result) if result end |
Instance Method Details
#/(path) ⇒ Object
Returns a Nokogiri::XML::NodeSet of elements matching the given path. Example: element/“author”.
343 344 345 346 347 |
# File 'lib/amazon/ecs.rb', line 343 def /(path) elements = @element/path return nil if elements.size == 0 elements end |
#attributes ⇒ Object
382 383 384 385 |
# File 'lib/amazon/ecs.rb', line 382 def attributes return unless self.elem self.elem.attributes end |
#elem ⇒ Object
Returns Nokogiri::XML::Element object
338 339 340 |
# File 'lib/amazon/ecs.rb', line 338 def elem @element end |
#get(path = '.') ⇒ Object
Get the text value of the given path, leave empty to retrieve current element value.
363 364 365 |
# File 'lib/amazon/ecs.rb', line 363 def get(path='.') Element.get(@element, path) end |
#get_array(path = '.') ⇒ Object
Get the array values of the given path.
373 374 375 |
# File 'lib/amazon/ecs.rb', line 373 def get_array(path='.') Element.get_array(@element, path) end |
#get_element(path) ⇒ Object
Similar with search_and_convert but always return first element if more than one elements found
357 358 359 360 |
# File 'lib/amazon/ecs.rb', line 357 def get_element(path) elements = get_elements(path) elements[0] if elements end |
#get_elements(path) ⇒ Object
Return an array of Amazon::Element matching the given path
350 351 352 353 354 |
# File 'lib/amazon/ecs.rb', line 350 def get_elements(path) elements = self./(path) return unless elements elements = elements.map{|element| Element.new(element)} end |
#get_hash(path = '.') ⇒ Object
Get the children element text values in hash format with the element names as the hash keys.
378 379 380 |
# File 'lib/amazon/ecs.rb', line 378 def get_hash(path='.') Element.get_hash(@element, path) end |
#get_unescaped(path = '.') ⇒ Object
Get the unescaped HTML text of the given path.
368 369 370 |
# File 'lib/amazon/ecs.rb', line 368 def get_unescaped(path='.') Element.get_unescaped(@element, path) end |
#to_s ⇒ Object
387 388 389 |
# File 'lib/amazon/ecs.rb', line 387 def to_s elem.to_s if elem end |